
import pytest

@pytest.fixture
def mapping_response():
    return {'responseHeader': {'QTime': 0, 'params': {'mm': '100%', 'q': '*:*', 'defType': 'edismax', 'facet_min_count': '1', 'hl': 'false', 'start': '0', 'q.op': 'AND', 'fq': 'subject_id:"MONDO\\:0020121" OR object_id:"MONDO\\:0020121"', 'facet.mincount': '1', 'rows': '20', 'facet': 'true'}}, 'response': {'num_found': 9, 'start': 0, 'docs': [{'subject_id': 'MONDO:0020121', 'subject_label': 'muscular dystrophy', 'predicate_id': 'skos:exactMatch', 'object_id': 'Orphanet:98473', 'object_label': 'Muscular dystrophy', 'mapping_justification': 'semapv:UnspecifiedMatching', 'mapping_source': ['mondo.sssom'], 'id': '303ae2ac-9e44-4908-a03a-3abf85e3eb7c', 'highlighting': None}, {'subject_id': 'MONDO:0020121', 'subject_label': 'muscular dystrophy', 'predicate_id': 'skos:exactMatch', 'object_id': 'icd11.foundation:1464662404', 'mapping_justification': 'semapv:UnspecifiedMatching', 'mapping_source': ['mondo.sssom'], 'id': '07d3ed5f-ffee-4260-9634-88baf2d0efd7', 'highlighting': None}, {'subject_id': 'MONDO:0020121', 'subject_label': 'muscular dystrophy', 'predicate_id': 'skos:exactMatch', 'object_id': 'MEDGEN:44527', 'mapping_justification': 'semapv:UnspecifiedMatching', 'mapping_source': ['mondo.sssom'], 'id': '9df8e97f-c647-4722-9d11-282c2f075db0', 'highlighting': None}, {'subject_id': 'MONDO:0020121', 'subject_label': 'muscular dystrophy', 'predicate_id': 'skos:exactMatch', 'object_id': 'DOID:9884', 'object_label': 'muscular dystrophy', 'mapping_justification': 'semapv:UnspecifiedMatching', 'mapping_source': ['mondo.sssom'], 'id': '1168db96-6f5e-4314-9ac7-bb336773a63a', 'highlighting': None}, {'subject_id': 'MONDO:0020121', 'subject_label': 'muscular dystrophy', 'predicate_id': 'skos:exactMatch', 'object_id': 'MESH:D009136', 'mapping_justification': 'semapv:UnspecifiedMatching', 'mapping_source': ['mondo.sssom'], 'id': 'e0234338-69e4-4d5c-ad84-bee6a8d63e60', 'highlighting': None}, {'subject_id': 'MONDO:0020121', 'subject_label': 'muscular dystrophy', 'predicate_id': 'skos:exactMatch', 'object_id': 'NCIT:C84910', 'object_label': 'Muscular Dystrophy', 'mapping_justification': 'semapv:UnspecifiedMatching', 'mapping_source': ['mondo.sssom'], 'id': 'd1c63d51-0f60-4655-8adb-6afe7bf25e82', 'highlighting': None}, {'subject_id': 'MONDO:0020121', 'subject_label': 'muscular dystrophy', 'predicate_id': 'skos:exactMatch', 'object_id': 'SCTID:73297009', 'mapping_justification': 'semapv:UnspecifiedMatching', 'mapping_source': ['mondo.sssom'], 'id': '20b96ad0-4d60-4ef4-b0ee-01cc333b7018', 'highlighting': None}, {'subject_id': 'MONDO:0020121', 'subject_label': 'muscular dystrophy', 'predicate_id': 'skos:exactMatch', 'object_id': 'UMLS:C0026850', 'mapping_justification': 'semapv:UnspecifiedMatching', 'mapping_source': ['mondo.sssom'], 'id': '76a45fb2-63f3-4d3f-abae-a3bddd37919f', 'highlighting': None}, {'subject_id': 'MONDO:0020121', 'subject_label': 'muscular dystrophy', 'predicate_id': 'skos:exactMatch', 'object_id': 'ICD10CM:G71.0', 'object_label': 'Muscular dystrophy', 'mapping_justification': 'semapv:UnspecifiedMatching', 'mapping_source': ['mondo.sssom'], 'id': 'afbdaf20-a6f8-49a8-b1b5-4c85478b9f19', 'highlighting': None}]}, 'facet_counts': {'facet_fields': {}, 'facet_queries': {}}, 'highlighting': {}}
