
import pytest

@pytest.fixture
def histopheno_response():
    return {'responseHeader': {'QTime': 1, 'params': {'facet.query': ['object_closure:"UPHENO:0002964"', 'object_closure:"UPHENO:0004523"', 'object_closure:"UPHENO:0002764"', 'object_closure:"UPHENO:0002635"', 'object_closure:"UPHENO:0003020"', 'object_closure:"UPHENO:0080362"', 'object_closure:"HP:0001939"', 'object_closure:"UPHENO:0002642"', 'object_closure:"UPHENO:0002833"', 'object_closure:"HP:0002664"', 'object_closure:"UPHENO:0004459"', 'object_closure:"UPHENO:0002948"', 'object_closure:"UPHENO:0003116"', 'object_closure:"UPHENO:0002816"', 'object_closure:"UPHENO:0004536"', 'object_closure:"HP:0000598"', 'object_closure:"UPHENO:0002712"', 'object_closure:"UPHENO:0075949"', 'object_closure:"UPHENO:0049874"', 'object_closure:"UPHENO:0003013"'], 'mm': '100%', 'q': '*:*', 'defType': 'edismax', 'facet_min_count': '1', 'hl': 'false', 'start': '0', 'q.op': 'AND', 'fq': 'subject:"MONDO:0020121" OR subject_closure:"MONDO:0020121"', 'facet.mincount': '1', 'rows': '0', 'facet': 'true'}}, 'response': {'num_found': 4655, 'start': 0, 'docs': []}, 'facet_counts': {'facet_fields': {}, 'facet_queries': {'object_closure:"UPHENO:0002964"': 524, 'object_closure:"UPHENO:0004523"': 1042, 'object_closure:"UPHENO:0002764"': 608, 'object_closure:"UPHENO:0002635"': 51, 'object_closure:"UPHENO:0003020"': 300, 'object_closure:"UPHENO:0080362"': 0, 'object_closure:"HP:0001939"': 229, 'object_closure:"UPHENO:0002642"': 48, 'object_closure:"UPHENO:0002833"': 188, 'object_closure:"HP:0002664"': 7, 'object_closure:"UPHENO:0004459"': 204, 'object_closure:"UPHENO:0002948"': 28, 'object_closure:"UPHENO:0003116"': 40, 'object_closure:"UPHENO:0002816"': 2135, 'object_closure:"UPHENO:0004536"': 161, 'object_closure:"HP:0000598"': 23, 'object_closure:"UPHENO:0002712"': 187, 'object_closure:"UPHENO:0075949"': 22, 'object_closure:"UPHENO:0049874"': 33, 'object_closure:"UPHENO:0003013"': 1}}, 'highlighting': {}}
