<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8" />
    <meta name="viewport" content="width=device-width, initial-scale=1.0" />

    <!-- basic -->
    <title>{{ title }}</title>
    <meta name="title" content="{{ title }}" />
    <meta name="description" content="{{ description }}" />

    <!-- open graph -->
    <meta property="og:type" content="website" />
    <meta property="og:url" content="{{ url }}" />
    <meta property="og:title" content="{{ title }}" />
    <meta property="og:description" content="{{ description }}" />
    <meta property="og:image" content="{{ image }}" />
    <meta property="og:site_name" content="Monarch Initiative" />

    <!-- twitter -->
    <meta property="twitter:card" content="summary_large_image" />
    <meta property="twitter:url" content="{{ url }}" />
    <meta property="twitter:title" content="{{ title }}" />
    <meta property="twitter:description" content="{{ description }}" />
    <meta property="twitter:image" content="{{ image }}" />

    <!-- redirect browsers to the real page -->
    <meta http-equiv="refresh" content="0;url={{ url }}" />
</head>
<body>
    <h1>{{ title }}</h1>
    <p>{{ description }}</p>
    <p>Redirecting to <a href="{{ url }}">{{ url }}</a>...</p>
</body>
</html>
